#!/bin/sh

set -e

# Root CA
if [ ! -f ./root-ca-key.pem ]; then
    echo "Generating root CA key"
    openssl genrsa -out ./root-ca-key.pem 2048
fi
if [ ! -f ./opensearch/root-ca.pem ]; then
    echo "Generating root CA cert"
    openssl req -new -x509 -sha256 -key root-ca-key.pem -subj "/C=CZ/ST=PRAGUE/L=PRAGUE/O=APPTOCLOUD/OU=SYSLOG/CN=root" -out ./opensearch/root-ca.pem -days 3650
fi

# Node cert 1
echo "Generating node cert 1"
openssl genrsa -out node1-key-temp.pem 2048
openssl pkcs8 -inform PEM -outform PEM -in node1-key-temp.pem -topk8 -nocrypt -v1 PBE-SHA1-3DES -out ./opensearch/node1-key.pem
openssl req -new -key ./opensearch/node1-key.pem -subj "/C=CZ/ST=PRAGUE/L=PRAGUE/O=APPTOCLOUD/OU=SYSLOG/CN=opensearch-node1" -out node1.csr
openssl x509 -req -in node1.csr -CA ./opensearch/root-ca.pem -CAkey root-ca-key.pem -CAcreateserial -sha256 -out ./opensearch/node1.pem -days 3650
rm node1-key-temp.pem
rm node1.csr

# Node cert 2
echo "Generating node cert 2"
openssl genrsa -out node2-key-temp.pem 2048
openssl pkcs8 -inform PEM -outform PEM -in node2-key-temp.pem -topk8 -nocrypt -v1 PBE-SHA1-3DES -out ./opensearch/node2-key.pem
openssl req -new -key ./opensearch/node2-key.pem -subj "/C=CZ/ST=PRAGUE/L=PRAGUE/O=APPTOCLOUD/OU=SYSLOG/CN=opensearch-node2" -out node2.csr
openssl x509 -req -in node2.csr -CA ./opensearch/root-ca.pem -CAkey root-ca-key.pem -CAcreateserial -sha256 -out ./opensearch/node2.pem -days 3650
rm node2-key-temp.pem
rm node2.csr

# Node cert 3
echo "Generating node cert 3"
openssl genrsa -out node3-key-temp.pem 2048
openssl pkcs8 -inform PEM -outform PEM -in node3-key-temp.pem -topk8 -nocrypt -v1 PBE-SHA1-3DES -out ./opensearch/node3-key.pem
openssl req -new -key ./opensearch/node3-key.pem -subj "/C=CZ/ST=PRAGUE/L=PRAGUE/O=APPTOCLOUD/OU=SYSLOG/CN=opensearch-node3" -out node3.csr
openssl x509 -req -in node3.csr -CA ./opensearch/root-ca.pem -CAkey root-ca-key.pem -CAcreateserial -sha256 -out ./opensearch/node3.pem -days 3650
rm node3-key-temp.pem
rm node3.csr

# Admin cert
openssl genrsa -out admin-key-temp.pem 2048
openssl pkcs8 -inform PEM -outform PEM -in admin-key-temp.pem -topk8 -nocrypt -v1 PBE-SHA1-3DES -out ./opensearch/admin-key.pem
openssl req -new -key ./opensearch/admin-key.pem -subj "/C=CZ/ST=PRAGUE/L=PRAGUE/O=APPTOCLOUD/OU=SYSLOG/CN=ADMIN" -out admin.csr
openssl x509 -req -in admin.csr -CA ./opensearch/root-ca.pem -CAkey root-ca-key.pem -CAcreateserial -sha256 -out ./opensearch/admin.pem -days 3650
rm admin-key-temp.pem
rm admin.csr

# Client cert
openssl genrsa -out client-key-temp.pem 2048
openssl pkcs8 -inform PEM -outform PEM -in client-key-temp.pem -topk8 -nocrypt -v1 PBE-SHA1-3DES -out client-key.pem
openssl req -new -key client-key.pem -subj "/C=CZ/ST=PRAGUE/L=PRAGUE/O=APPTOCLOUD/OU=SYSLOG/CN=client" -out client.csr
openssl x509 -req -in client.csr -CA ./opensearch/root-ca.pem -CAkey root-ca-key.pem -CAcreateserial -sha256 -out client.pem -days 3650
rm client-key-temp.pem
rm client.csr
